@@ -295,11 +295,13 @@ class FormaPagamentoConfiguracaoEnviarResource(PagamentoConfiguracaoBaseResource
             return resultado
         except (MeioDePagamentoNaoDefinido, MeioDePagamentoNaoEncontrado, PluginNaoEncontrado), ex:
             return {"erro": u"pagador: {}".format(ex)}, 500
-        except IntegrityError, ex:
-            return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
-        except Exception, ex:
-            import traceback
-            return {"erro": u"Servidor: {} - {}".format(ex, traceback.format_exc())}, 500
+
+        # TODO: Vamos tratar de outro jeito, mas por enquanto deixar assim para aparecer no sentry
+        # except IntegrityError, ex:
+        #     return {"erro": u"Erro no banco de dados: {}".format(ex)}, 500
+        # except Exception, ex:
+        #     import traceback
+        #     return {"erro": u"Servidor: {} - {}".format(ex, traceback.format_exc())}, 500
 
 
 class FormaPagamentoRetornoResource(PagamentoConfiguracaoBaseResource):
